@@ -36,7 +36,6 @@ import datetime
 import dbus
 import distro_info
 import os
-import subprocess
 
 import HweSupportStatus.consts
 from .Core.LivePatchSocket import LivePatchSocket
@@ -159,12 +158,11 @@ class InternalDialog(BuilderDialog):
 
         if not active:
             if self._is_livepatch_supported() and \
-               self.settings_button and \
                self.settings.get_int('launch-count') >= 4:
-                self.set_desc(_("<b>Tip:</b> You can use Livepatch with "
-                                "Ubuntu Pro to keep your computer more "
-                                "secure between restarts."))
-                self.settings_button.set_label(_("Settings & Pro…"))
+                self.set_desc(_("<b>Tip:</b> You can use Livepatch to "
+                                "keep your computer more secure between "
+                                "restarts."))
+                self.settings_button.set_label(_("Settings & Livepatch…"))
             return
 
         needs_reschedule = False
@@ -296,22 +294,6 @@ class UnsupportedDialog(DistUpgradeDialog):
         DistUpgradeDialog.run(self, parent)
 
 
-class NoUpgradeForYouDialog(InternalDialog):
-    def __init__(self, window_main, meta_release, arch):
-        InternalDialog.__init__(self, window_main)
-        self.set_header(_("Sorry, there are no more upgrades for this system"))
-        # Translators: this is an Ubuntu version name like "Ubuntu 12.04"
-        self.set_desc(_("\nThere will not be any further Ubuntu releases "
-                        "for this system's '%s' architecture.\n\n"
-                        "Updates for Ubuntu %s will continue until "
-                        "2023-04-26.\n\nIf you reinstall Ubuntu from "
-                        "ubuntu.com/download, future upgrades will "
-                        "be available.") %
-                       (arch, meta_release.current_dist_version))
-        self.focus_button = self.add_button(Gtk.STOCK_OK,
-                                            self.window_main.close)
-
-
 class PartialUpgradeDialog(InternalDialog):
     def __init__(self, window_main):
         InternalDialog.__init__(self, window_main)
@@ -386,8 +368,8 @@ class NeedRestartDialog(InternalDialog):
         Dialog.start(self)
         # Turn off close button
         self.window_main.realize()
-        self.window_main.get_window().set_functions(Gdk.WMFunction.MOVE |
-                                                    Gdk.WMFunction.MINIMIZE)
+        self.window_main.get_window().set_functions(Gdk.WMFunction.MOVE
+                                                    | Gdk.WMFunction.MINIMIZE)
 
     def restart(self, *args, **kwargs):
         self._request_reboot_via_session_manager()
