@@ -36,7 +36,6 @@ from UpdateManager.Core.MetaRelease import (
     MetaReleaseCore,
     MetaReleaseParseError,
 )
-from UpdateManager.Core.utils import url_downloadable
 
 CURDIR = os.path.dirname(os.path.abspath(__file__))
 
@@ -102,18 +101,6 @@ class TestMetaReleaseCore(unittest.TestCase):
                              "but expected '%s''" % (current, new_dist.name,
                                                      next))
 
-    @unittest.skipUnless(url_downloadable(
-        "https://ubuntu.com", logging.debug),
-        "Could not reach https test site")
-    def test_https_url_downloadable(self):
-        with EnvironmentVarGuard() as environ:
-            logging.debug("no proxy, https address")
-            del environ["http_proxy"]
-            install_opener(None)
-            self.assertTrue(url_downloadable("https://ubuntu.com",
-                            logging.debug),
-                            "download https with no proxy failed")
-
     def test_url_downloadable(self):
         from UpdateManager.Core.utils import url_downloadable
         with EnvironmentVarGuard() as environ:
@@ -144,12 +131,12 @@ class TestMetaReleaseCore(unittest.TestCase):
                             logging.debug),
                             "download with no proxy failed")
 
-            logging.debug("no proxy, no valid address")
+            logging.debug("no proxy, no valid adress")
             self.assertFalse(url_downloadable("http://archive.ubuntu.com/xxx",
                                               logging.debug),
                              "download with no proxy failed")
 
-            logging.debug("proxy, no valid address")
+            logging.debug("proxy, no valid adress")
             environ["http_proxy"] = "http://localhost:%s" % self.port
             install_opener(None)
             self.assertFalse(url_downloadable("http://archive.ubuntu.com/xxx",
@@ -167,7 +154,7 @@ class TestMetaReleaseCore(unittest.TestCase):
     def test_html_uri_real(self):
         # test parsing of a meta-releaes file from the server
         with EnvironmentVarGuard() as environ:
-            environ["META_RELEASE_FAKE_CODENAME"] = "bionic"
+            environ["META_RELEASE_FAKE_CODENAME"] = "lucid"
             meta = MetaReleaseCore(forceDownload=True)
             while meta.downloading:
                 time.sleep(0.1)
@@ -178,6 +165,22 @@ class TestMetaReleaseCore(unittest.TestCase):
             self.assertTrue(len(data) > 0)
             self.assertTrue("<html>" in data)
 
+    @patch("UpdateManager.Core.MetaRelease.MetaReleaseCore.download")
+    @patch("UpdateManager.Core.MetaRelease.distro_info.UbuntuDistroInfo"
+           ".is_lts")
+    def test_prompt_lts_ignored_for_non_lts(self, mock_is_lts, mock_download):
+        with tempfile.NamedTemporaryFile() as f:
+            # for non-LTS, Prompt=lts should not change the METARELEASE_URI
+            mock_is_lts.return_value = False
+            f.write("""
+[DEFAULT]
+Prompt=lts
+""".encode("utf-8"))
+            f.flush()
+            with patch.object(MetaReleaseCore, "CONF", f.name):
+                meta = MetaReleaseCore()
+            self.assertNotEqual(meta.METARELEASE_URI, meta.METARELEASE_URI_LTS)
+
     @patch("UpdateManager.Core.MetaRelease.MetaReleaseCore.download")
     def test_parse_fails_for_all_non_tagfiles(self, mock_download):
         meta = MetaReleaseCore()
